@@ -254,7 +254,7 @@ EXCMD(CMD_caddbuffer,	"caddbuffer",	ex_cbuffer,
 	EX_RANGE|EX_WORD1|EX_TRLBAR,
 	ADDR_OTHER),
 EXCMD(CMD_caddexpr,	"caddexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM,
 	ADDR_NONE),
 EXCMD(CMD_caddfile,	"caddfile",	ex_cfile,
 	EX_TRLBAR|EX_FILE1,
@@ -296,7 +296,7 @@ EXCMD(CMD_center,	"center",	ex_align,
 	EX_TRLBAR|EX_RANGE|EX_WHOLEFOLD|EX_EXTRA|EX_CMDWIN|EX_MODIFY,
 	ADDR_LINES),
 EXCMD(CMD_cexpr,	"cexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR|EX_BANG,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_BANG,
 	ADDR_NONE),
 EXCMD(CMD_cfile,	"cfile",	ex_cfile,
 	EX_TRLBAR|EX_FILE1|EX_BANG,
@@ -314,7 +314,7 @@ EXCMD(CMD_cgetbuffer,	"cgetbuffer",	ex_cbuffer,
 	EX_RANGE|EX_WORD1|EX_TRLBAR,
 	ADDR_OTHER),
 EXCMD(CMD_cgetexpr,	"cgetexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM,
 	ADDR_NONE),
 EXCMD(CMD_chdir,	"chdir",	ex_cd,
 	EX_BANG|EX_FILE1|EX_TRLBAR|EX_CMDWIN,
@@ -746,7 +746,7 @@ EXCMD(CMD_language,	"language",	ex_language,
 	EX_EXTRA|EX_TRLBAR|EX_CMDWIN,
 	ADDR_NONE),
 EXCMD(CMD_laddexpr,	"laddexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM,
 	ADDR_NONE),
 EXCMD(CMD_laddbuffer,	"laddbuffer",	ex_cbuffer,
 	EX_RANGE|EX_WORD1|EX_TRLBAR,
@@ -797,7 +797,7 @@ EXCMD(CMD_let,		"let",		ex_let,
 	EX_EXTRA|EX_NOTRLCOM|EX_SBOXOK|EX_CMDWIN,
 	ADDR_NONE),
 EXCMD(CMD_lexpr,	"lexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR|EX_BANG,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_BANG,
 	ADDR_NONE),
 EXCMD(CMD_lfile,	"lfile",	ex_cfile,
 	EX_TRLBAR|EX_FILE1|EX_BANG,
@@ -815,7 +815,7 @@ EXCMD(CMD_lgetbuffer,	"lgetbuffer",	ex_cbuffer,
 	EX_RANGE|EX_WORD1|EX_TRLBAR,
 	ADDR_OTHER),
 EXCMD(CMD_lgetexpr,	"lgetexpr",	ex_cexpr,
-	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM|EX_TRLBAR,
+	EX_NEEDARG|EX_WORD1|EX_NOTRLCOM,
 	ADDR_NONE),
 EXCMD(CMD_lgrep,	"lgrep",	ex_make,
 	EX_RANGE|EX_BANG|EX_NEEDARG|EX_EXTRA|EX_NOTRLCOM|EX_TRLBAR|EX_XFILE,
@@ -1841,7 +1841,7 @@ struct exarg
     char_u	*(*getline)(int, void *, int, int);
     void	*cookie;	// argument for getline()
 #ifdef FEAT_EVAL
-    struct condstack *cstack;	// condition stack for ":if" etc.
+    cstack_T	*cstack;	// condition stack for ":if" etc.
 #endif
     long	verbose_save;	 // saved value of p_verbose
     int		save_msg_silent; // saved value of msg_silent
